translate.misc.selector.Naked

Package translate :: Package misc :: Module selector :: Class Naked |
[hide private]
[frames] | no frames]

# Class Naked

source code

Naked object style dispatch base class.

Instance Methods | [hide private]
_is_exposed(self, obj) Determine if obj should be exposed. | source code
__call__(self, environ, start_response) Dispatch to the method named by the next bit of PATH_INFO. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Static Methods | [hide private]
_not_found(environ, start_response) Respond with a 404. | source code

Class Variables | [hide private]
| _expose_all = `True` hash(x)
| _exposed = `True` hash(x)

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### _is_exposed(self, obj) | source code
Determine if obj should be exposed. If self._expose_all is True, always return True. Otherwise, look at obj._exposed.